from xbase_util.db.bean.TaskTemplateBean import TaskTemplateBean


class TaskTemplateDao:
    def __init__(self,Session):
        self.Session = Session

    def addTemplate(self, data):
        with self.Session() as session:
            try:
                b = TaskTemplateBean()
                b.config_id = data.config_id
                b.flow_id = data.flow_id
                b.description = data.description
                b.is_scheduled = data.is_scheduled
                b.scheduled_start_time = data.scheduled_start_time
                b.scheduled_interval_minutes = data.scheduled_interval_minutes
                b.scheduled_period_minutes = data.scheduled_period_minutes
                session.add(b)
                session.commit()
            except Exception as e:
                print(e)
                session.rollback()

    def changeTemplate(self, data):
        with self.Session() as session:
            try:
                bean = session.query(TaskTemplateBean).first()
                bean.config_id = data.config_id
                bean.flow_id = data.flow_id
                bean.description = data.description
                session.commit()
            except Exception as e:
                print(e)
                session.rollback()

    def get_list(self):
        with self.Session() as session:
            try:
                temp_list = session.query(TaskTemplateBean).all()
                return temp_list
            except Exception as e:
                session.rollback()
                print(e)
                return []

    def delete_template(self, id):
        with self.Session() as session:
            try:
                bean = session.query(TaskTemplateBean).filter_by(id=id).first()
                session.delete(bean)
                session.commit()
                return True
            except Exception as e:
                session.rollback()
                print(e)
                return False



from sqlalchemy import Column, Integer, String, Boolean

from xbase_util.db.bean import DbBase


class TaskTemplateBean(DbBase):
    __tablename__ = 'tasktemplatebean'
    id = Column(Integer, primary_key=True)

    config_id = Column(String)
    flow_id = Column(String)
    description = Column(String)

    is_scheduled = Column(Boolean, default=False)  # 是否为定时任务
    scheduled_start_time = Column(String, nullable=True)  # 定时任务的开始时间
    scheduled_interval_minutes = Column(Integer, nullable=True)  # 定时任务的执行间隔（以分钟为单位）
    scheduled_period_minutes = Column(Integer, nullable=True)  # 要获取的时间段（以分钟为单位）

    def to_dict(self):
        return {
            "id": self.id,
            "config_id": self.config_id,
            "flow_id": self.flow_id,
            "description": self.description,
            "is_scheduled": self.is_scheduled,
            "start_time": self.scheduled_start_time,
            "interval_minutes": self.scheduled_interval_minutes,
        }



from xbase_util.db.bean.CurrentConfigBean import CurrentConfig


class CurrentConfigDao:
    def __init__(self,Session):
        self.Session = Session

    def set_current_config(self, id, desc):
        with self.Session() as session:
            try:
                session.query(CurrentConfig).delete()
                session.add(CurrentConfig(config_id=id, description=desc))
                session.commit()
            except Exception as e:
                session.rollback()
                print(f"Error: {e}")

    def get_current_config(self):
        with self.Session() as session:
            try:
                return session.query(CurrentConfig).first()
            except Exception as e:
                session.rollback()
                print(f"Error: {e}")